@@ -2,7 +2,7 @@
    expressed by lezer's built-in tokenizer. */
 
 import {ExternalTokenizer, ContextTracker} from "@lezer/lr"
-import {insertSemi, noSemi, incdec, incdecPrefix, questionDot,
+import {insertSemi, noSemi, noSemiType, incdec, incdecPrefix, questionDot,
         spaces, newline, BlockComment, LineComment,
         JSXStartTag, Dialect_jsx} from "./parser.terms.js"
 
@@ -10,7 +10,7 @@ const space = [9, 10, 11, 12, 13, 32, 133, 160, 5760, 8192, 8193, 8194, 8195, 81
                8201, 8202, 8232, 8233, 8239, 8287, 12288]
 
 const braceR = 125, semicolon = 59, slash = 47, star = 42, plus = 43, minus = 45, lt = 60, comma = 44,
-      question = 63, dot = 46
+      question = 63, dot = 46, bracketL = 91
 
 export const trackNewline = new ContextTracker({
   start: false,
@@ -34,6 +34,10 @@ export const noSemicolon = new ExternalTokenizer((input, stack) => {
     input.acceptToken(noSemi)
 }, {contextual: true})
 
+export const noSemicolonType = new ExternalTokenizer((input, stack) => {
+  if (input.next == bracketL && !stack.context) input.acceptToken(noSemiType)
+}, {contextual: true})
+
 export const operatorToken = new ExternalTokenizer((input, stack) => {
   let {next} = input
   if (next == plus || next == minus) {
